<!DOCTYPE HTML>
<html>
  <header>
    <meta name="HandheldFriendly" content="true" />
    <meta name="MobileOptimized" content="320" />
    <meta charset="utf-8">
    <meta name="viewport" content="initial-scale=1.0, maximum-scale=1.0, width=device-width, user-scalable=no" />
    <link rel="stylesheet" href="{{ 'static/style' | relative_url }}">
  </header>
  <body class='grid-container'>
    <div class='navbar'>{% block navbar %}{% include "navbar.html" %}{% endblock %}</div>
    <div class='left_side'>{% block left_side %}{% endblock %}</div>
    <div class='content'>{% block contents %}{% endblock %}</div>
    <div class='right_side'>{% block right_side %}{% endblock %}</div>
    <div class='footer'>{% block footer %}{% include "footer.html" %}{% endblock %}</div>
    <script src="{{ 'static/expand_script' | relative_url }}"></script>
  </body>
</html>
