html {
  font-family: Georgia, serif;
}
.grid-container {
  display: grid;
  grid-template-columns: 1fr minmax(0, 50em) 1fr;
  grid-template-rows: 2.5em 1fr 2.5em;
  gap: 0px 0px;
  grid-template-areas:
    "navbar navbar navbar"
    "left content right"
    "left footer right";
  height: 100vh;
}
.content {
  grid-area: content;
  padding-bottom: 1em;
}
.left_side {
  grid-area: left;
}
.right_side {
  grid-area: right;
}
.navbar {
  grid-area: navbar;
}
.footer {
  grid-area: footer;
}

.undecorated {
  text-decoration: none;
  color: inherit;
}
.subdued_link {
  opacity: 0.6;
}
.subdued_link:hover {
  opacity: 1.0;
}

.card:hover {
  opacity: 0.6;
}
.card_title {
  font-size: 1.5em;
  font-weight: bold;
}
.card_header {
  margin-bottom: 1em;
}
.card_body {
  margin-left: 2em;
}

.navbar_container {
  display: flex;
  justify-content: space-between;
  align-items: center;
}
.navbar_title {
  font-size: 2em;
  margin-left: 0.5em;
}
.navbar_search {
  display: flex;
  margin-right: 1.5em;
}
.navbar_search_input {
  font-size: 1.2em;
  margin-right: 0.5em;
}
.navbar_search_button {
  font-size: 1.2em;
}

.footer_container {
  display: flex;
  justify-content: flex-end;
}

.query_overview {
  display: flex;
  justify-content: flex-end;
  margin: 0.5em;
}

.dataset_title {
  font-size: 1.9em;
  font-weight: bold;
}
.field_title {
  font-size: 1.7em;
  font-weight: bold;
  font-family: monospace;
}
.field_type {
  font-size: 1.7em;
  font-weight: 400;
  font-family: monospace;
}
.field_header {
  display: flex;
  justify-content: space-between;
  margin-top: 1.3em;
  margin-bottom: 0.7em;
}
.field_body {
  margin-left: 2em;
}

.tags {
  display: flex;
  margin-bottom: 0.5em;
  flex-wrap: wrap;
}
.tag {
  margin-right: 0.25em;
  white-space: nowrap;
  cursor: pointer;
}

.tag.black > span {
  border-color: #222222;
}
.tag.black > .tag_label {
  color: white;
  background-color: #505050;
}

.tag.grey > span {
  border-color: #9c9c9c;
}
.tag.grey > .tag_label {
  color: black;
  background-color: #cccccc;
}

.tag.red > span {
  border-color: hsl(348, 74%, 45%);
}
.tag.red > .tag_label {
  color: black;
  background-color: hsl(348, 100%, 70%);
}

.tag.yellow > span {
  border-color: hsl(48, 100%, 43%);
}
.tag.yellow > .tag_label {
  color: black;
  background-color: hsl(48, 100%, 67%);
}

.tag.green > span {
  border-color: hsl(171, 76%, 39%);
}
.tag.green > .tag_label {
  color: black;
  background-color: hsl(171, 100%, 41%);
}

.tag.purple > span {
  border-color: #69218d;
}
.tag.purple > .tag_label {
  color: white;
  background-color: #7920a5;
}

.tag_label {
  padding: 0.1em;
  padding-left: 0.6em;
  padding-right: 0.2em;
  border-top-left-radius: 2em;
  border-bottom-left-radius: 2em;
  border-width: 3px;
  border-style: solid;
}
.tag_label:only-child {
  border-top-right-radius: 2em;
  border-bottom-right-radius: 2em;
  padding-right: 0.6em;
}
.tag_value {
  padding: 0.1em;
  padding-right: 0.6em;
  padding-left: 0.2em;
  border-top-right-radius: 2em;
  border-bottom-right-radius: 2em;
  border-width: 3px;
  border-left-width: 0px;
  border-style: solid;
}

.divider {
  margin: 1em;
  margin-left: 4em;
  margin-right: 4em;
}

a.headerlink {
  text-decoration: none;
  visibility: hidden;
  padding-left: 0.1em;
  padding-right: 0.1em;
}
.anchorable:hover > a.headerlink {
  visibility: visible;
  color: lightgray;
}
.anchorable a.headerlink:hover {
  color: darkslategrey;
  background-color: lightgray;
}

pre {
  background-color:hsl(0, 0%, 96%);
  padding: 1em;
}
.default_hidden {
  display: none
}

.link_sidebar {
  display: flex;
  flex-direction: column;
  align-items: flex-start;
  padding-left: 4em;
  padding-top: 4em;
}
